@@ -8,6 +8,7 @@ from braintree.coinbase_account import CoinbaseAccount
 from braintree.android_pay_card import AndroidPayCard
 from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
 from braintree.venmo_account import VenmoAccount
+from braintree.us_bank_account import UsBankAccount
 from braintree.unknown_payment_method import UnknownPaymentMethod
 from braintree.error_result import ErrorResult
 from braintree.exceptions.not_found_error import NotFoundError
@@ -53,19 +54,27 @@ class PaymentMethodGateway(object):
         self.config.http().delete(self.config.base_merchant_path() + "/payment_methods/any/" + payment_method_token)
         return SuccessfulResult()
 
-    def grant(self, payment_method_token, allow_vaulting):
+    def grant(self, payment_method_token, options=None):
         if payment_method_token is None or not str(payment_method_token).strip():
-            raise ValueError
+            raise ValueError("payment method token cannot be empty or blank")
 
         try:
+            if isinstance(options, bool):
+                options = { "allow_vaulting": options }
+            elif options is None:
+                options = {}
+            self.options = options
+
+            params = {
+                       "payment_method": {
+                           "shared_payment_method_token": payment_method_token
+                        }
+                     }
+            params["payment_method"].update(options),
+
             return self._post(
                 "/payment_methods/grant",
-                {
-                    "payment_method": {
-                        "shared_payment_method_token": payment_method_token,
-                        "allow_vaulting": allow_vaulting
-                    }
-                },
+                params,
                 "payment_method_nonce"
             )
         except NotFoundError:
@@ -124,6 +133,8 @@ class PaymentMethodGateway(object):
             return CoinbaseAccount(self.gateway, response["coinbase_account"])
         elif "venmo_account" in response:
             return VenmoAccount(self.gateway, response["venmo_account"])
+        elif "us_bank_account" in response:
+            return UsBankAccount(self.gateway, response["us_bank_account"])
         elif "payment_method_nonce" in response:
             return PaymentMethodNonce(self.gateway, response["payment_method_nonce"])
         elif "success" in response:
